================
nova-trame API
================

--------------
Typing Classes
--------------

.. _api_types:

.. _api_trame_tuple:
.. autoclass:: nova.trame.utils.types.TrameTuple
    :members:

---------------
Theme Component
---------------

.. _api_theme:

.. autoclass:: nova.trame.ThemedApp
    :members:
    :special-members: __init__

-----------------
Layout Components
-----------------

.. _api_layouts:

.. autoclass:: nova.trame.view.layouts.GridLayout
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.layouts.HBoxLayout
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.layouts.VBoxLayout
    :members:
    :special-members: __init__

--------------------------
General Purpose Components
--------------------------

.. _api_components:

.. autoclass:: nova.trame.view.components.InputField
    :members:
    :special-members: __new__

.. _api_remotefileinput:

.. autoclass:: nova.trame.view.components.RemoteFileInput
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.components.FileUpload
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.components.DataSelector
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.utilities.local_storage.LocalStorageManager
    :members:
    :special-members: __init__

-------------------------
Job Management Components
-------------------------

.. autoclass:: nova.trame.view.components.ExecutionButtons
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.components.ProgressBar
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.components.ToolOutputWindows
    :members:
    :special-members: __init__

------------------------
Visualization Components
------------------------

.. _api_interactive2dplot:

.. autoclass:: nova.trame.view.components.visualization.Interactive2DPlot
    :members:
    :special-members: __init__

.. autoclass:: nova.trame.view.components.visualization.MatplotlibFigure
    :members:
    :special-members: __init__

--------------------
ORNL-only components
--------------------

.. autoclass:: nova.trame.view.components.ornl.NeutronDataSelector
    :members:
    :special-members: __init__
